# python_template_test_pkg

## Using this template:

1. Replace `python_template_test_pkg` with the name of the package, and rename the directory.
2. Delete the `CHANGELOG.md` file.
3. Fill details in the `python_template_test_pkg/__init__.py` file.
4. Set the `PYPI_PASSWORD` secret.
